@@ -1,8 +1,7 @@
-(provide 'vm)
+;;(provide 'vm)
+;;(provide 'vm-version)
 
-(provide 'vm-version)
-
-(defconst vm-version "7.04"
+(defconst vm-version "7.17"
   "Version number of VM.")
 
 (defun vm-version ()
@@ -91,12 +90,12 @@
 
 (defun vm-multiple-fonts-possible-p ()
   (cond (vm-xemacs-p
-	 (memq (device-type) '(x mswindows)))
+	 (memq (device-type) '(x gtk mswindows)))
 	(vm-fsfemacs-p
 	 (memq window-system '(x mac w32 win32)))))
 
 (defun vm-images-possible-here-p ()
-  (or (and vm-xemacs-p (memq (device-type) '(x mswindows)))
+  (or (and vm-xemacs-p (memq (device-type) '(x gtk mswindows)))
       (and vm-fsfemacs-p window-system
 	   (or (fboundp 'image-type-available-p)
 	       (and (stringp vm-imagemagick-convert-program)
@@ -106,3 +105,6 @@
   (if (fboundp 'image-type-available-p)
       (image-type-available-p type)
     (or (featurep type) (eq type 'xbm))))
+
+(provide 'vm)
+(provide 'vm-version)
